import { Hono, Context } from 'hono';
import { Connection } from 'mariadb';
import User from '@slovo/models/User';
import Database from '@slovo/infrastructure/database';

const app = new Hono();

// add routes and methods here
app.post('/register', async (c: Context) => {
    // check if form (from the web app) or JSON (from a blank API call);
    let user: User;
    if (c.req.header('Content-Type') == 'application/json') {
        user = await c.req.json<User>();
    } else {
        user = await c.req.formData<User>();
    }


    const conn: Connection = await Database.getInstance().getConnection();
    const query = `INSERT INTO users (username, password) VALUES (?, ?)`;

    try {
        const results = await conn.query(query, [ user.username, user.password ]);

        console.log(results);
        return c.json({
            message: "Registration successful.",
        });
    } catch (e) {
        console.error(e);
        c.status(500);
        return c.json({
            message: "Error registering user."
        });
    }
});

export default app;
